#!/bin/bash

set -ex


#set -ex
# set option to stop on error, not continue
# x for debugging, writes out each line (more terminal output)

# arguments passed by OSTRICH:
#     rank      – The zero-based processor id of the processor that invoked the script.
#     trial     – For multi-start algorithms (i.e. DDSAU, MS-GML, and PSO-GML) the trial
#                 argument indicates which multi-start trial is currently underway.
#                 For all other algorithms the trial argument is set to 0.
#     counter   – The current count of model runs completed for the given rank and trial.
#     objective function category (ofcat) – A text string that categorizes the objective
#                 function value associated with the completed model run. User-defined model
#                 preservation scripts may wish to take different actions depending on the
#                 ofcat setting. Possible values are given below:
#                 - best           – For single-objective algorithms, an ofcat
#                                    value of "best" indicates that the completed
#                                    model run is the best solution obtained so far.
#                 - behavioral     – For uncertainty-based algorithms, an ofcat
#                                    value of "behavioral" indicates that the completed
#                                    model run is a behavioral solution.
#                 - non-behavioral – For uncertainty-based algorithms, an ofcat value
#                                    of "non- behavioral" indicates that the completed
#                                    model run is a non-behavioral solution.
#                 - dominated      – For multi-objective algorithms, an ofcat value of
#                                    "dominated" indicates that the completed model run
#                                    is a dominated solution.
#                 - non-dominated  – For multi-objective algorithms, an ofcat value of
#                                    "non- dominated" indicates that the completed model
#                                    run is a non-dominated solution based on the model
#                                    runs that have completed so far. Note that a non-
#                                    dominated solution may become dominated later in a
#                                    search.
#                 - other          – An ofcat value of "other" indicates that the completed
#                                    model run does not fit into any of the previously
#                                    listed categories. For example, in a single-objective
#                                    algorithm this would indicate that the completed model
#                                    run is not the best solution obtained so far.

args=("$@")
echo $#" arguments passed"
echo "arguments: "${args[0]} ${args[1]} ${args[2]} ${args[3]}

rank=${args[0]}
trial=${args[1]}
counter=${args[2]}
ofcat=${args[3]}

foldername='re-run_'${counter}

# remove folders that might still exist from previous runs
if [ -e ${foldername} ] ; then
    rm -r ${foldername}
fi

mkdir ${foldername}
    
cp -r model/output/ ${foldername}

exit 0
